# PyPass Password Manager v4.0

<p>An simple ,secure , trustable and Quantum Safe password Manager developed in Python3.</p>

Quick Installation
------------------

To Install from [PyPI](https://pypi.org/project/passwordsgo/):

Run the following commands in Linux terminal / Windows powershell / command prompt to install:-

```
pip install passwordsgo
```
Then simply type following to get started :-

```
passwordsgo
```
 
 ### Main Features and Highlights
 * It is fully Open Source!
 * It is Highly Portable and has robust Cross-Platform availability.
 * It Makes Password Reuse as securely as possible.
 * The code is Simple, Modular and Trustable which even beginners can audit for correctness.
 * It does not use any third party modules other than standard python libraries.
 * It is Practically very hard to use Brute-force attacks to recover user passwords.
 * It Uses Robust Offline Password Backup System to backup passwords. 
 
 
 ### Note
 * Code has been Open sourced For Educational and Research Purpose only.
 * Developers not responsible for Any Damage arising from use of this Software.
 
 ### Interested in our Project???
 * visit our screenshot gallery: https://github.com/Anish-M-code/PyPass/blob/master/screenshots/Gallery.md
 * Currently i consider this work as personal project so i don't expect public contributions.
 * Feel free to create an issue if you feel something is missing or broken.
 




